==> haskell-polysemy-1.5.0.0-7-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-polysemy.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 polysemy
version:              1.5.0.0
visibility:           public
id:                   polysemy-1.5.0.0-5yuwEEnYo7lDHyIsZca4Lw
key:                  polysemy-1.5.0.0-5yuwEEnYo7lDHyIsZca4Lw
license:              BSD-3-Clause
copyright:            2019 Sandy Maguire
maintainer:           sandy@sandymaguire.me
author:               Sandy Maguire
homepage:             https://github.com/polysemy-research/polysemy#readme
synopsis:             Higher-order, low-boilerplate free monads.
description:
    Please see the README on GitHub at <https://github.com/isovector/polysemy#readme>

category:             Language
abi:                  f7827fcc862e9af788eaf0ba018048ef
exposed:              True
exposed-modules:
    Polysemy Polysemy.Async Polysemy.AtomicState Polysemy.Bundle
    Polysemy.Embed Polysemy.Embed.Type Polysemy.Error Polysemy.Fail
    Polysemy.Fail.Type Polysemy.Final Polysemy.Fixpoint Polysemy.IO
    Polysemy.Input Polysemy.Internal Polysemy.Internal.Bundle
    Polysemy.Internal.Combinators Polysemy.Internal.CustomErrors
    Polysemy.Internal.CustomErrors.Redefined Polysemy.Internal.Fixpoint
    Polysemy.Internal.Forklift Polysemy.Internal.Kind
    Polysemy.Internal.NonDet Polysemy.Internal.Strategy
    Polysemy.Internal.TH.Common Polysemy.Internal.TH.Effect
    Polysemy.Internal.Tactics Polysemy.Internal.Union
    Polysemy.Internal.Writer Polysemy.Law Polysemy.Membership
    Polysemy.NonDet Polysemy.Output Polysemy.Reader Polysemy.Resource
    Polysemy.State Polysemy.State.Law Polysemy.Tagged Polysemy.Trace
    Polysemy.View Polysemy.Writer

hidden-modules:       Polysemy.Internal.PluginLookup Paths_polysemy
import-dirs:          /usr/lib/ghc-8.10.4/site-local/polysemy-1.5.0.0
library-dirs:         /usr/lib/ghc-8.10.4/site-local/polysemy-1.5.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/polysemy-1.5.0.0
hs-libraries:         HSpolysemy-1.5.0.0-5yuwEEnYo7lDHyIsZca4Lw
depends:
    QuickCheck-2.14.2-5SjNJKKsajAoAy0kcEsoV
    async-2.2.3-bRJqoep3gj749cy8sss28 base-4.14.1.0 containers-0.6.2.1
    first-class-families-0.8.0.1-E410xQMLP495NYCkVJ757V mtl-2.2.2
    stm-2.5.0.0 syb-0.7.2.1-IHzu7I6ikCoGwAbnu6OBXz
    template-haskell-2.16.0.0
    th-abstraction-0.4.2.0-CPMLTlyMgmr6dbHxHL95CG transformers-0.5.6.2
    type-errors-0.2.0.0-3hUctx0jRk79ALVzPwWPwM
    type-errors-pretty-0.0.1.1-92dcX015gWtBTzIooWLwwV
    unagi-chan-0.4.1.3-IgzEBwjbNCUH9joJxspiUf

haddock-interfaces:   /usr/share/doc/haskell-polysemy/html/polysemy.haddock
haddock-html:         /usr/share/doc/haskell-polysemy/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-polysemy-1.5.0.0-8-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-polysemy.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 polysemy
version:              1.5.0.0
visibility:           public
id:                   polysemy-1.5.0.0-Bajif39HorG9YBehscLgvM
key:                  polysemy-1.5.0.0-Bajif39HorG9YBehscLgvM
license:              BSD-3-Clause
copyright:            2019 Sandy Maguire
maintainer:           sandy@sandymaguire.me
author:               Sandy Maguire
homepage:             https://github.com/polysemy-research/polysemy#readme
synopsis:             Higher-order, low-boilerplate free monads.
description:
    Please see the README on GitHub at <https://github.com/isovector/polysemy#readme>

category:             Language
abi:                  cc390ebe5904a5864c5bfd65daa47901
exposed:              True
exposed-modules:
    Polysemy Polysemy.Async Polysemy.AtomicState Polysemy.Bundle
    Polysemy.Embed Polysemy.Embed.Type Polysemy.Error Polysemy.Fail
    Polysemy.Fail.Type Polysemy.Final Polysemy.Fixpoint Polysemy.IO
    Polysemy.Input Polysemy.Internal Polysemy.Internal.Bundle
    Polysemy.Internal.Combinators Polysemy.Internal.CustomErrors
    Polysemy.Internal.CustomErrors.Redefined Polysemy.Internal.Fixpoint
    Polysemy.Internal.Forklift Polysemy.Internal.Kind
    Polysemy.Internal.NonDet Polysemy.Internal.Strategy
    Polysemy.Internal.TH.Common Polysemy.Internal.TH.Effect
    Polysemy.Internal.Tactics Polysemy.Internal.Union
    Polysemy.Internal.Writer Polysemy.Law Polysemy.Membership
    Polysemy.NonDet Polysemy.Output Polysemy.Reader Polysemy.Resource
    Polysemy.State Polysemy.State.Law Polysemy.Tagged Polysemy.Trace
    Polysemy.View Polysemy.Writer

hidden-modules:       Polysemy.Internal.PluginLookup Paths_polysemy
import-dirs:          /usr/lib/ghc-8.10.4/site-local/polysemy-1.5.0.0
library-dirs:         /usr/lib/ghc-8.10.4/site-local/polysemy-1.5.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/polysemy-1.5.0.0
hs-libraries:         HSpolysemy-1.5.0.0-Bajif39HorG9YBehscLgvM
depends:
    QuickCheck-2.14.2-iylmRy9CGA787SUAAP3Uz
    async-2.2.3-EZZT7wQnIBTGEUrsu0pZys base-4.14.1.0 containers-0.6.2.1
    first-class-families-0.8.0.1-E410xQMLP495NYCkVJ757V mtl-2.2.2
    stm-2.5.0.0 syb-0.7.2.1-IHzu7I6ikCoGwAbnu6OBXz
    template-haskell-2.16.0.0
    th-abstraction-0.4.2.0-CPMLTlyMgmr6dbHxHL95CG transformers-0.5.6.2
    type-errors-0.2.0.0-3MSBaXjsXJ6K9K5Wefl61d
    type-errors-pretty-0.0.1.1-FdSEay9QrsZD9c3qrZjVUh
    unagi-chan-0.4.1.3-BxSgboelWuRDvo0dyHtsDd

haddock-interfaces:   /usr/share/doc/haskell-polysemy/html/polysemy.haddock
haddock-html:         /usr/share/doc/haskell-polysemy/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
